@@ -36,7 +36,7 @@ use warnings;
 use File::Spec::Functions qw( catfile catdir );
 use Readonly;
 
-our $VERSION = '2.1001';
+our $VERSION = '2.11';
 $VERSION =~ s/_//ms;
 
 Readonly my %LIBRARIES_S => {
@@ -47,12 +47,14 @@ Readonly my %LIBRARIES_S => {
 		'mysql5101'     => 'DBD-mysql-4.012-MSWin32-x86-multi-thread-5.10.0.par',
 		'mysql5115'     => undef,
 		'mysql5120'     => undef,
+		'mysql5121'     => undef,
 		'mysqllib'      => '32bit-gcc3/MySQLLibraries-20100121.zip',
 		'pari589'       => 'Math-Pari-2.010801-MSWin32-x86-multi-thread-5.8.9.par',
 		'pari5100'      => '32bit-gcc3/Math-Pari-2.01080603-MSWin32-x86-multi-thread-5.10.1.par',
 		'pari5101'      => '32bit-gcc3/Math-Pari-2.01080603-MSWin32-x86-multi-thread-5.10.1.par',
 		'pari5115'      => '32bit-gcc3/Math-Pari-2.01080603-MSWin32-x86-multi-thread-5.11.5.par',
 		'pari5120'      => undef,
+		'pari5121'      => undef,
 		'zlib'          => '32bit-gcc4/zlib-1.2.3-bin_20091126.zip',
 		'libiconv'      => '32bit-gcc4/libiconv-1.13.1-bin_20091126.zip',
 		'libxml2'       => '32bit-gcc4/libxml2-2.7.3-bin_20091126.zip',
@@ -75,6 +77,7 @@ Readonly my %LIBRARIES_S => {
 		'mpfr'          => '32bit-gcc4/mpfr-2.4.2-bin_20100306.zip',
 		'libmysql'      => '32bit-gcc4/mysql-5.1.44-bin_20100304.zip',
 		'freeglut'      => '32bit-gcc4/freeglut-2.6.0-bin_20100213.zip',
+		'libssh2'       => '32bit-gcc4/libssh2-1.2.5-bin_20100520.zip',
 	},
 	'32bit-gcc4' => {
 		'patch'         => '32bit-gcc4/patch-2.5.9-7-bin_20100110_20100303.zip',
@@ -83,12 +86,14 @@ Readonly my %LIBRARIES_S => {
 		'mysql5101'     => undef,
 		'mysql5115'     => undef,
 		'mysql5120'     => undef,
+		'mysql5121'     => undef,
 		'mysqllib'      => '32bit-gcc4/mysql-5.1.44-bin_20100304.zip',
 		'pari589'       => undef,
 		'pari5100'      => undef,
 		'pari5101'      => undef,
 		'pari5115'      => '32bit-gcc4/Math-Pari-2.01080604-MSWin32-x86-multi-thread-5.11.5.par',
 		'pari5120'      => '32bit-gcc4/Math-Pari-2.01080604-MSWin32-x86-multi-thread-5.12.0.par',
+		'pari5121'      => '32bit-gcc4/Math-Pari-2.01080604-MSWin32-x86-multi-thread-5.12.0.par',
 		'zlib'          => '32bit-gcc4/zlib-1.2.3-bin_20091126.zip',
 		'libiconv'      => '32bit-gcc4/libiconv-1.13.1-bin_20091126.zip',
 		'libxml2'       => '32bit-gcc4/libxml2-2.7.3-bin_20091126.zip',
@@ -111,6 +116,7 @@ Readonly my %LIBRARIES_S => {
 		'mpfr'          => '32bit-gcc4/mpfr-2.4.2-bin_20100306.zip',
 		'libmysql'      => '32bit-gcc4/mysql-5.1.44-bin_20100304.zip',
 		'freeglut'      => '32bit-gcc4/freeglut-2.6.0-bin_20100213.zip',
+		'libssh2'       => '32bit-gcc4/libssh2-1.2.5-bin_20100520.zip',
 	},
 	'64bit-gcc4' => {
 		'patch'         => '64bit-gcc4/patch-2.5.9-7-bin_20100110_20100303.zip',
@@ -119,12 +125,14 @@ Readonly my %LIBRARIES_S => {
 		'mysql5101'     => undef,
 		'mysql5115'     => undef,
 		'mysql5120'     => undef,
+		'mysql5121'     => undef,
 		'mysqllib'      => undef,
 		'pari589'       => undef,
 		'pari5100'      => undef,
 		'pari5101'      => undef,
 		'pari5115'      => undef,
 		'pari5120'      => undef,
+		'pari5121'      => undef,
 		'zlib'          => '64bit-gcc4/zlib-1.2.3-bin_20100110.zip',
 		'libiconv'      => '64bit-gcc4/libiconv-1.13.1-bin_20100110.zip',
 		'libxml2'       => '64bit-gcc4/libxml2-2.7.3-bin_20100110.zip',
@@ -147,6 +155,7 @@ Readonly my %LIBRARIES_S => {
 		'mpfr'          => '64bit-gcc4/mpfr-2.4.2-bin_20100306.zip',
 		'libmysql'      => '64bit-gcc4/mysql-5.1.44-bin_20100304.zip',
 		'freeglut'      => '64bit-gcc4/freeglut-2.6.0-bin_20100213.zip',
+		'libssh2'       => '64bit-gcc4/libssh2-1.2.5-bin_20100520.zip',
 	},
 };
 
@@ -303,18 +312,22 @@ sub install_ppm {
 			die("Failed to create '$ppmdir' directory");
 		}
 
-		# Install PPM itself
+		# Install PPM itself.
+		# See http://www.perhammer.com/2008/07/subversion-in-url-revision-browsing.html
+		# for description of strange URL.
 		my $share = $self->dist_dir();
-		if ($self->portable()) {
+		if ($self->portable() && (12 < $self->perl_major_version()) ) {
 			$self->install_distribution_from_file(
 				mod_name      => 'PPM',
 				file          => catfile($share, 'modules', 'PPM-0.01_03.tar.gz'),
+				url           => 'http://svn.ali.as/cpan/!svn/bc/12117/trunk/' . 'Perl-Dist-Strawberry/share/modules/PPM-0.01_03.tar.gz',
 				makefilepl_param => ['INSTALLDIRS=site'],
 			);		
 		} else {
 			$self->install_distribution_from_file(
 				mod_name      => 'PPM',
 				file          => catfile($share, 'modules', 'PPM-0.01_03.tar.gz'),
+				url           => 'http://svn.ali.as/cpan/!svn/bc/12117/trunk/' . 'Perl-Dist-Strawberry/share/modules/PPM-0.01_03.tar.gz',
 				makefilepl_param => ['INSTALLDIRS=vendor'],
 			);		
 		}
@@ -402,12 +415,15 @@ This method should only be called at during the install_modules phase.
 
 sub install_pari {
 	my $self = shift;
-	
-	my $url = $self->get_library_file_versioned('pari');
+
+	my $file = $self->get_library_file_versioned('pari');
+
+	my ($version) = $file =~ m{-(2 [.] \d+)-}msx;
 	
 	my $filelist = $self->install_par(
-	  name => 'Math::Pari', 
-	  url => $self->_binary_url($url)
+	  name      => 'Math::Pari', 
+	  url       => $self->_binary_url($file),
+	  dist_info => "ILYAZ/modules/Math-Pari-$version.tar.gz",
 	);
 
 	return 1;
@@ -441,6 +457,37 @@ sub install_librarypack {
 	return 1;
 }
 
+=head2 install_libmysql
+
+  $dist->install_libmysql()
+
+The C<install_libmysql> method installs a library defined in 
+C<%Perl::Dist::Strawberry::LIBRARIES_S>.
+
+=cut
+
+sub install_libmysql {
+	my $self = shift;
+	
+	my $filelist = $self->install_binary(
+		name       => 'libmysql',
+		url        => $self->_binary_url($self->get_library_file('libmysql')),
+		install_to => q{.}
+	);
+	$self->insert_fragment('libmysql', $filelist);
+
+	# Fix RT#58079.
+	my $source = $self->file(qw(c bin libmysql_.dll));
+	my $destination = $self->file(qw(perl vendor lib auto DBD mysql libmysql_.dll));
+	if (! -f $source) { # 64-bit package has __ instead of _...
+		$source = $self->file(qw(c bin libmysql__.dll));
+		$destination = $self->file(qw(perl vendor lib auto DBD mysql libmysql__.dll));
+	}
+	$self->copy_file($source, $destination);
+	$self->add_file(source => $destination, fragment => 'libmysql');
+	
+	return 1;
+}
 
 
 =pod
